# pihome
Play local music to your google home

# Requirements
- Python (3.7+)
- Pip 3

# Running
```
git clone https://github.com/StarNumber12046/pihome
cd pihome
cd server
pip3 install flask
pip3 install pychromecast
python3 server.py
```
Now open `localhost:8080` on your browser
